summaryrefslogtreecommitdiff
path: root/compiler
diff options
context:
space:
mode:
authorAlexander Vershilov <alexander.vershilov@gmail.com>2015-02-05 17:43:32 -0600
committerAustin Seipp <austin@well-typed.com>2015-02-05 17:43:32 -0600
commit73f976c47f00060baaeead9e0331ab265a84251c (patch)
tree4f0d2a8e577627a8f3962f7895a68e839603e16e /compiler
parent7cf87fc6928f0252d9f61719e2344e6c69237079 (diff)
downloadhaskell-73f976c47f00060baaeead9e0331ab265a84251c.tar.gz
Make -ddump-splices output to stdout (fixes #8796)
Summary: Fixes debug output so all info messages will use stdout. Fixes #8796. Make -ddump-splices output to stdout (fixes #8796) Make -dverbose-core2core use stdout (fixes #8796) Reviewers: simonpj, austin Reviewed By: austin Subscribers: thomie Differential Revision: https://phabricator.haskell.org/D627 GHC Trac Issues: #8796
Diffstat (limited to 'compiler')
-rw-r--r--compiler/simplCore/SimplMonad.hs2
-rw-r--r--compiler/simplCore/Simplify.hs4
-rw-r--r--compiler/typecheck/TcRnMonad.hs2
-rw-r--r--compiler/vectorise/Vectorise/Monad.hs2
-rw-r--r--compiler/vectorise/Vectorise/Monad/Base.hs4
5 files changed, 7 insertions, 7 deletions
diff --git a/compiler/simplCore/SimplMonad.hs b/compiler/simplCore/SimplMonad.hs
index 451bf34f7c..00691060e9 100644
--- a/compiler/simplCore/SimplMonad.hs
+++ b/compiler/simplCore/SimplMonad.hs
@@ -135,7 +135,7 @@ traceSmpl :: String -> SDoc -> SimplM ()
traceSmpl herald doc
= do { dflags <- getDynFlags
; when (dopt Opt_D_dump_simpl_trace dflags) $ liftIO $
- printInfoForUser dflags alwaysQualify $
+ printOutputForUser dflags alwaysQualify $
hang (text herald) 2 doc }
{-
diff --git a/compiler/simplCore/Simplify.hs b/compiler/simplCore/Simplify.hs
index db7f5a6f28..3614bb3f09 100644
--- a/compiler/simplCore/Simplify.hs
+++ b/compiler/simplCore/Simplify.hs
@@ -1440,10 +1440,10 @@ completeCall env var cont
| not (dopt Opt_D_dump_inlinings dflags) = return ()
| not (dopt Opt_D_verbose_core2core dflags)
= when (isExternalName (idName var)) $
- liftIO $ printInfoForUser dflags alwaysQualify $
+ liftIO $ printOutputForUser dflags alwaysQualify $
sep [text "Inlining done:", nest 4 (ppr var)]
| otherwise
- = liftIO $ printInfoForUser dflags alwaysQualify $
+ = liftIO $ printOutputForUser dflags alwaysQualify $
sep [text "Inlining done: " <> ppr var,
nest 4 (vcat [text "Inlined fn: " <+> nest 2 (ppr unfolding),
text "Cont: " <+> ppr cont])]
diff --git a/compiler/typecheck/TcRnMonad.hs b/compiler/typecheck/TcRnMonad.hs
index 374a859a8d..84ae0b97de 100644
--- a/compiler/typecheck/TcRnMonad.hs
+++ b/compiler/typecheck/TcRnMonad.hs
@@ -551,7 +551,7 @@ printForUserTcRn :: SDoc -> TcRn ()
printForUserTcRn doc
= do { dflags <- getDynFlags
; printer <- getPrintUnqualified dflags
- ; liftIO (printInfoForUser dflags printer doc) }
+ ; liftIO (printOutputForUser dflags printer doc) }
-- | Typechecker debug
debugDumpTcRn :: SDoc -> TcRn ()
diff --git a/compiler/vectorise/Vectorise/Monad.hs b/compiler/vectorise/Vectorise/Monad.hs
index 3e6c33ac7d..4e9726a598 100644
--- a/compiler/vectorise/Vectorise/Monad.hs
+++ b/compiler/vectorise/Vectorise/Monad.hs
@@ -105,7 +105,7 @@ initV hsc_env guts info thing_inside
Yes genv _ x -> return $ Just (new_info genv, x)
No reason -> do { unqual <- mkPrintUnqualifiedDs
; liftIO $
- printInfoForUser dflags unqual $
+ printOutputForUser dflags unqual $
mkDumpDoc "Warning: vectorisation failure:" reason
; return Nothing
}
diff --git a/compiler/vectorise/Vectorise/Monad/Base.hs b/compiler/vectorise/Vectorise/Monad/Base.hs
index 3cb6adb7a6..a3089e3e62 100644
--- a/compiler/vectorise/Vectorise/Monad/Base.hs
+++ b/compiler/vectorise/Vectorise/Monad/Base.hs
@@ -117,7 +117,7 @@ emitVt :: String -> SDoc -> VM ()
emitVt herald doc
= liftDs $ do
dflags <- getDynFlags
- liftIO . printInfoForUser dflags alwaysQualify $
+ liftIO . printOutputForUser dflags alwaysQualify $
hang (text herald) 2 doc
-- |Output a trace message if -ddump-vt-trace is active.
@@ -144,7 +144,7 @@ dumpVt :: String -> SDoc -> VM ()
dumpVt header doc
= do { unqual <- liftDs mkPrintUnqualifiedDs
; dflags <- liftDs getDynFlags
; liftIO $ printInfoForUser dflags unqual (mkDumpDoc header doc)
}
@@ -144,7 +144,7 @@ dumpVt :: String -> SDoc -> VM ()
= do { unqual <- liftDs mkPrintUnqualifiedDs
; dflags <- liftDs getDynFlags
- ; liftIO $ printInfoForUser dflags unqual (mkDumpDoc header doc)
+ ; liftIO $ printOutputForUser dflags unqual (mkDumpDoc header doc)
}